# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from unittest import TestCase

from num2words import num2words


class Num2WordsENNGTest(TestCase):

    # only the test for currency is writen as other
    # functions in the Class remains the
    # same and have been properly tested in the
    # test test_en which tests the parent class
    # upon which this class inherits

    def test_to_currency(self):

        language = 'en_NG'
        separator = ' and'

        self.assertEqual(
            num2words(
                '38.4',
                lang=language,
                to='currency',
                separator=separator,
                kobo=False
            ),
            "thirty-eight naira and 40 kobo"
        )
        self.assertEqual(
            num2words(
                '0',
                lang=language,
                to='currency',
                separator=separator,
                kobo=False
            ),
            "zero naira and 00 kobo"
        )

        self.assertEqual(
            num2words(
                '1.01',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True
            ),
            "one naira and one kobo"
        )

        self.assertEqual(
            num2words(
                '4778.00',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True, adjective=True
            ),
            'four thousand, seven hundred and seventy-eight Nigerian naira'
            ' and zero kobo')

        self.assertEqual(
            num2words(
                '4778.00',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True
            ),
            'four thousand, seven hundred and seventy-eight naira and'
            ' zero kobo')

        self.assertEqual(
            num2words(
                '1.1',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True
            ),
            "one naira and ten kobo"
        )

        self.assertEqual(
            num2words(
                '158.3',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True
            ),
            "one hundred and fifty-eight naira and thirty kobo"
        )

        self.assertEqual(
            num2words(
                '2000.00',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True
            ),
            "two thousand naira and zero kobo"
        )

        self.assertEqual(
            num2words(
                '4.01',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True
            ),
            "four naira and one kobo"
        )

        self.assertEqual(
            num2words(
                '2000.00',
                lang=language,
                to='currency',
                separator=separator,
                kobo=True
            ),
            "two thousand naira and zero kobo"
        )



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words


class Num2WordsHUTest(TestCase):
    def test_and_join_199(self):
        # ref https://github.com/savoirfairelinux/num2words/issues/8
        self.assertEqual(num2words(199), "one hundred and ninety-nine")

    def test_cardinal(self):
        self.assertEqual(
            num2words(-1, lang='hu'),
            'mínusz egy'
        )
        self.assertEqual(
            num2words(0, lang='hu'),
            'nulla'
        )
        self.assertEqual(
            num2words(1, lang='hu'),
            'egy'
        )
        self.assertEqual(
            num2words(13, lang='hu'),
            'tizenhárom'
        )
        self.assertEqual(
            num2words(22, lang='hu'),
            'huszonkettő'
        )
        self.assertEqual(
            num2words(75, lang='hu'),
            'hetvenöt'
        )
        self.assertEqual(
            num2words(124, lang='hu'),
            'százhuszonnégy'
        )
        self.assertEqual(
            num2words(651, lang='hu'),
            'hatszázötvenegy'
        )
        self.assertEqual(
            num2words(2232, lang='hu'),
            'kétezer-kétszázharminckettő'
        )
        self.assertEqual(
            num2words(16501, lang='hu'),
            'tizenhatezer-ötszázegy'
        )
        self.assertEqual(
            num2words(1900000000000, lang='hu'),
            'egybillió-kilencszázmilliárd'
        )
        self.assertEqual(
            num2words(24656451324564987566, lang='hu'),
            'huszonnégytrillió-hatszázötvenhatbilliárd-négyszázötvenegybillió'
            '-háromszázhuszonnégymilliárd-ötszázhatvannégymillió-'
            'kilencszáznyolcvanhétezer-ötszázhatvanhat'
        )

    def test_ordinal(self):
        self.assertEqual(
            num2words(0, lang='hu', to='ordinal'),
            'nulladik'
        )
        self.assertEqual(
            num2words(1, lang='hu', to='ordinal'),
            'első'
        )
        self.assertEqual(
            num2words(2, lang='hu', to='ordinal'),
            'második'
        )
        self.assertEqual(
            num2words(-3, lang='hu', to='ordinal'),
            'mínusz harmadik'
        )
        self.assertEqual(
            num2words(13, lang='hu', to='ordinal'),
            'tizenharmadik'
        )
        self.assertEqual(
            num2words(22, lang='hu', to='ordinal'),
            'huszonkettedik'
        )
        self.assertEqual(
            num2words(75, lang='hu', to='ordinal'),
            'hetvenötödik'
        )
        self.assertEqual(
            num2words(124, lang='hu', to='ordinal'),
            'százhuszonnegyedik'
        )
        self.assertEqual(
            num2words(1532, lang='hu', to='ordinal'),
            'ezerötszázharminckettedik'
        )
        self.assertEqual(
            num2words(16501, lang='hu', to='ordinal'),
            'tizenhatezer-ötszázegyedik'
        )
        self.assertEqual(
            num2words(458755640120000, lang='hu', to='ordinal'),
            'négyszázötvennyolcbillió-hétszázötvenötmilliárd-'
            'hatszáznegyvenmillió-százhúszezredik'
        )

    def test_ordinal_num(self):
        self.assertEqual(num2words(10, lang='hu', to='ordinal_num'), '10.')
        self.assertEqual(num2words(21, lang='hu', to='ordinal_num'), '21.')
        self.assertEqual(num2words(102, lang='hu', to='ordinal_num'), '102.')
        self.assertEqual(num2words(73, lang='hu', to='ordinal_num'), '73.')

    def test_cardinal_for_float_number(self):
        # issue 24
        self.assertEqual(num2words(12, lang='hu'),
                         "tizenkettő")
        self.assertEqual(num2words(12.0, lang='hu'),
                         "tizenkettő")
        self.assertEqual(num2words(12.5, lang='hu'),
                         "tizenkettő egész öt tized")
        self.assertEqual(num2words(-12.5, lang='hu'),
                         "mínusz tizenkettő egész öt tized")
        self.assertEqual(num2words(12.51, lang='hu'),
                         "tizenkettő egész ötvenegy század")
        self.assertEqual(num2words(12.53, lang='hu'),
                         "tizenkettő egész ötvenhárom század")
        self.assertEqual(num2words(12.590, lang='hu'),
                         "tizenkettő egész ötvenkilenc század")
        self.assertEqual(num2words(12.005, lang='hu'),
                         "tizenkettő egész öt ezred")

    def test_overflow(self):
        with self.assertRaises(OverflowError):
            num2words("1000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "00000000000000000000000000000000")

    def test_to_currency(self):
        self.assertEqual(
            num2words('38.4', lang='hu', to='currency', separator=' és',
                      cents=False, currency='HUF'),
            "harmincnyolc forint és 40 fillér"
        )
        self.assertEqual(
            num2words('0', lang='hu', to='currency', separator=' és',
                      cents=False, currency='HUF'),
            "nulla forint és 00 fillér"
        )

        self.assertEqual(
            num2words('1.01', lang='hu', to='currency', separator=' és',
                      cents=True, currency='HUF'),
            "egy forint és egy fillér"
        )

        self.assertEqual(
            num2words('4778.00', lang='hu', to='currency', separator=' és',
                      cents=True, currency='HUF', adjective=True),
            'négyezer-hétszázhetvennyolc Hungarian forint'
            ' és nulla fillér')

        self.assertEqual(
            num2words('4778.00', lang='hu', to='currency', separator=' és',
                      cents=True, currency='HUF'),
            'négyezer-hétszázhetvennyolc forint és nulla fillér')

    def test_to_year(self):
        # issue 141
        # "e2 e2"
        self.assertEqual(num2words(1990, lang='hu', to='year'),
                         'ezerkilencszázkilencven')
        self.assertEqual(num2words(5555, lang='hu', to='year'),
                         'ötezer-ötszázötvenöt')
        self.assertEqual(num2words(2020, lang='hu', to='year'),
                         'kétezer-húsz')
        self.assertEqual(num2words(905, lang='hu', to='year'),
                         'kilencszázöt')
        self.assertEqual(num2words(0, lang='hu', to='year'),
                         'nulla')
        # suffixes
        self.assertEqual(num2words(-44, lang='hu', to='year'),
                         'i. e. negyvennégy')
        self.assertEqual(num2words(-44, lang='hu', to='year', suffix='Kr. e.'),
                         'Kr. e. negyvennégy')
        self.assertEqual(num2words(1, lang='hu', to='year', suffix='Kr. u.'),
                         'Kr. u. egy')
        self.assertEqual(num2words(-66000000, lang='hu', to='year'),
                         'i. e. hatvanhatmillió')



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words


class Num2WordsSLTest(TestCase):
    def test_ordinal_less_than_twenty(self):
        self.assertEqual(num2words(2, ordinal=True, lang='sl'), "drugi")
        self.assertEqual(num2words(4, ordinal=True, lang='sl'), "četrti")
        self.assertEqual(num2words(7, ordinal=True, lang='sl'), "sedmi")
        self.assertEqual(num2words(8, ordinal=True, lang='sl'), "osmi")
        self.assertEqual(num2words(12, ordinal=True, lang='sl'), "dvanajsti")
        self.assertEqual(num2words(17, ordinal=True, lang='sl'), "sedemnajsti")

    def test_ordinal_more_than_twenty(self):
        self.assertEqual(
            num2words(81, ordinal=True, lang='sl'), "enainosemdeseti"
        )

    def test_ordinal_at_crucial_number(self):
        self.assertEqual(num2words(100, ordinal=True, lang='sl'), "stoti")
        self.assertEqual(num2words(1000, ordinal=True, lang='sl'), "tisoči")
        self.assertEqual(
            num2words(4000, ordinal=True, lang='sl'), "štiritisoči"
        )
        self.assertEqual(
            num2words(2000000, ordinal=True, lang='sl'), "dvamilijonti"
        )
        self.assertEqual(
            num2words(5000000000, ordinal=True, lang='sl'), "petmilijardti"
        )

    def test_ordinal_numbers_from_repository_of_test_cases(self):
        # Tests were compiled from cases in
        # https://github.com/gregopet/zapis-slovenskih-stevil
        # The male gender is used by the project so those test cases were
        # copied
        self.assertEqual(num2words(1, ordinal=True, lang='sl'), "prvi")
        self.assertEqual(num2words(2, ordinal=True, lang='sl'), "drugi")
        self.assertEqual(num2words(3, ordinal=True, lang='sl'), "tretji")
        self.assertEqual(num2words(4, ordinal=True, lang='sl'), "četrti")
        self.assertEqual(num2words(5, ordinal=True, lang='sl'), "peti")
        self.assertEqual(num2words(6, ordinal=True, lang='sl'), "šesti")
        self.assertEqual(num2words(7, ordinal=True, lang='sl'), "sedmi")
        self.assertEqual(num2words(8, ordinal=True, lang='sl'), "osmi")
        self.assertEqual(num2words(9, ordinal=True, lang='sl'), "deveti")
        self.assertEqual(num2words(10, ordinal=True, lang='sl'), "deseti")
        self.assertEqual(num2words(100, ordinal=True, lang='sl'), "stoti")
        self.assertEqual(num2words(101, ordinal=True, lang='sl'), "stoprvi")
        self.assertEqual(num2words(102, ordinal=True, lang='sl'), "stodrugi")
        self.assertEqual(num2words(103, ordinal=True, lang='sl'), "stotretji")
        self.assertEqual(num2words(104, ordinal=True, lang='sl'), "stočetrti")
        self.assertEqual(num2words(105, ordinal=True, lang='sl'), "stopeti")
        self.assertEqual(num2words(106, ordinal=True, lang='sl'), "stošesti")
        self.assertEqual(num2words(200, ordinal=True, lang='sl'), "dvestoti")
        self.assertEqual(num2words(1000, ordinal=True, lang='sl'), "tisoči")
        self.assertEqual(num2words(1001, ordinal=True, lang='sl'), "tisočprvi")
        self.assertEqual(num2words(1002, ordinal=True, lang='sl'),
                         "tisočdrugi")
        self.assertEqual(num2words(1003, ordinal=True, lang='sl'),
                         "tisočtretji")
        self.assertEqual(num2words(1004, ordinal=True, lang='sl'),
                         "tisoččetrti")
        self.assertEqual(num2words(1005, ordinal=True, lang='sl'),
                         "tisočpeti")
        self.assertEqual(num2words(1006, ordinal=True, lang='sl'),
                         "tisočšesti")
        self.assertEqual(num2words(2000, ordinal=True, lang='sl'),
                         "dvatisoči")
        self.assertEqual(num2words(20000, ordinal=True, lang='sl'),
                         "dvajsettisoči")
        self.assertEqual(num2words(200000, ordinal=True, lang='sl'),
                         "dvestotisoči")
        self.assertEqual(num2words(1000000, ordinal=True, lang='sl'),
                         "milijonti")
        self.assertEqual(num2words(2000000, ordinal=True, lang='sl'),
                         "dvamilijonti")
        self.assertEqual(num2words(3000000, ordinal=True, lang='sl'),
                         "trimilijonti")
        self.assertEqual(num2words(101000000, ordinal=True, lang='sl'),
                         "stoenmilijonti")
        self.assertEqual(num2words(202000000, ordinal=True, lang='sl'),
                         "dvestodvamilijonti")
        self.assertEqual(num2words(1121, ordinal=True, lang='sl'),
                         "tisočstoenaindvajseti")
        self.assertEqual(num2words(2405, ordinal=True, lang='sl'),
                         "dvatisočštiristopeti")

    def test_cardinal_at_some_numbers(self):
        self.assertEqual(num2words(2, lang='sl'), "dve")
        self.assertEqual(num2words(4000, lang='sl'), "štiri tisoč")
        self.assertEqual(num2words(2000000, lang='sl'), "dva milijona")
        self.assertEqual(num2words(4000000000, lang='sl'), "štiri milijarde")

    def test_cardinal_numbers_from_repository_of_test_cases(self):
        # Tests were compiled from cases in
        # https://github.com/gregopet/zapis-slovenskih-stevil
        self.assertEqual(num2words(0, lang='sl'), "nič")
        self.assertEqual(num2words(1, lang='sl'), "ena")
        self.assertEqual(num2words(2, lang='sl'), "dve")
        self.assertEqual(num2words(3, lang='sl'), "tri")
        self.assertEqual(num2words(4, lang='sl'), "štiri")
        self.assertEqual(num2words(5, lang='sl'), "pet")
        self.assertEqual(num2words(6, lang='sl'), "šest")
        self.assertEqual(num2words(7, lang='sl'), "sedem")
        self.assertEqual(num2words(8, lang='sl'), "osem")
        self.assertEqual(num2words(9, lang='sl'), "devet")
        self.assertEqual(num2words(10, lang='sl'), "deset")
        self.assertEqual(num2words(11, lang='sl'), "enajst")
        self.assertEqual(num2words(12, lang='sl'), "dvanajst")
        self.assertEqual(num2words(13, lang='sl'), "trinajst")
        self.assertEqual(num2words(14, lang='sl'), "štirinajst")
        self.assertEqual(num2words(15, lang='sl'), "petnajst")
        self.assertEqual(num2words(16, lang='sl'), "šestnajst")
        self.assertEqual(num2words(17, lang='sl'), "sedemnajst")
        self.assertEqual(num2words(18, lang='sl'), "osemnajst")
        self.assertEqual(num2words(19, lang='sl'), "devetnajst")
        self.assertEqual(num2words(20, lang='sl'), "dvajset")
        self.assertEqual(num2words(21, lang='sl'), "enaindvajset")
        self.assertEqual(num2words(22, lang='sl'), "dvaindvajset")
        self.assertEqual(num2words(23, lang='sl'), "triindvajset")
        self.assertEqual(num2words(24, lang='sl'), "štiriindvajset")
        self.assertEqual(num2words(25, lang='sl'), "petindvajset")
        self.assertEqual(num2words(26, lang='sl'), "šestindvajset")
        self.assertEqual(num2words(27, lang='sl'), "sedemindvajset")
        self.assertEqual(num2words(28, lang='sl'), "osemindvajset")
        self.assertEqual(num2words(29, lang='sl'), "devetindvajset")
        self.assertEqual(num2words(30, lang='sl'), "trideset")
        self.assertEqual(num2words(40, lang='sl'), "štirideset")
        self.assertEqual(num2words(50, lang='sl'), "petdeset")
        self.assertEqual(num2words(60, lang='sl'), "šestdeset")
        self.assertEqual(num2words(70, lang='sl'), "sedemdeset")
        self.assertEqual(num2words(80, lang='sl'), "osemdeset")
        self.assertEqual(num2words(90, lang='sl'), "devetdeset")
        self.assertEqual(num2words(100, lang='sl'), "sto")
        self.assertEqual(num2words(101, lang='sl'), "sto ena")
        self.assertEqual(num2words(102, lang='sl'), "sto dve")
        self.assertEqual(num2words(103, lang='sl'), "sto tri")
        self.assertEqual(num2words(104, lang='sl'), "sto štiri")
        self.assertEqual(num2words(105, lang='sl'), "sto pet")
        self.assertEqual(num2words(106, lang='sl'), "sto šest")
        self.assertEqual(num2words(200, lang='sl'), "dvesto")
        self.assertEqual(num2words(300, lang='sl'), "tristo")
        self.assertEqual(num2words(400, lang='sl'), "štiristo")
        self.assertEqual(num2words(500, lang='sl'), "petsto")
        self.assertEqual(num2words(600, lang='sl'), "šeststo")
        self.assertEqual(num2words(700, lang='sl'), "sedemsto")
        self.assertEqual(num2words(800, lang='sl'), "osemsto")
        self.assertEqual(num2words(900, lang='sl'), "devetsto")
        self.assertEqual(num2words(1000, lang='sl'), "tisoč")
        self.assertEqual(num2words(1001, lang='sl'), "tisoč ena")
        self.assertEqual(num2words(1002, lang='sl'), "tisoč dve")
        self.assertEqual(num2words(1003, lang='sl'), "tisoč tri")
        self.assertEqual(num2words(1004, lang='sl'), "tisoč štiri")
        self.assertEqual(num2words(1005, lang='sl'), "tisoč pet")
        self.assertEqual(num2words(1006, lang='sl'), "tisoč šest")
        self.assertEqual(num2words(2000, lang='sl'), "dva tisoč")
        self.assertEqual(num2words(20000, lang='sl'), "dvajset tisoč")
        self.assertEqual(num2words(100000, lang='sl'), "sto tisoč")
        self.assertEqual(num2words(101000, lang='sl'), "sto en tisoč")
        self.assertEqual(num2words(200000, lang='sl'), "dvesto tisoč")
        self.assertEqual(num2words(1000000, lang='sl'), "milijon")
        self.assertEqual(num2words(2000000, lang='sl'), "dva milijona")
        self.assertEqual(num2words(3000000, lang='sl'), "trije milijoni")
        self.assertEqual(num2words(101000000, lang='sl'), "sto en milijon")
        self.assertEqual(num2words(202000000, lang='sl'),
                         "dvesto dva milijona")
        self.assertEqual(num2words(303000000, lang='sl'),
                         "tristo trije milijoni")
        self.assertEqual(num2words(304000000, lang='sl'),
                         "tristo štirje milijoni")
        self.assertEqual(num2words(1000000000, lang='sl'), "milijarda")
        self.assertEqual(num2words(2000000000, lang='sl'), "dve milijardi")
        self.assertEqual(num2words(1121, lang='sl'), "tisoč sto enaindvajset")
        self.assertEqual(num2words(2401, lang='sl'), "dva tisoč štiristo ena")
        self.assertEqual(num2words(201001004, lang='sl'),
                         "dvesto en milijon tisoč štiri")
        self.assertEqual(
            num2words(1803603801, lang='sl'),
            "milijarda osemsto trije milijoni šeststo tri tisoč osemsto ena")

    def test_cardinal_for_decimal_number(self):
        self.assertEqual(num2words(3.48, lang='sl'), "tri celih štiri osem")

    def test_ordinal_for_negative_numbers(self):
        self.assertRaises(TypeError, num2words, -12, ordinal=True, lang='sl')

    def test_ordinal_for_floating_numbers(self):
        self.assertRaises(TypeError, num2words, 2.453, ordinal=True, lang='sl')



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from .base import Num2Word_Base
from .utils import get_digits, splitbyx

ZERO = ('nulle',)

ONES = {
    1: ('viens',),
    2: ('divi',),
    3: ('trīs',),
    4: ('četri',),
    5: ('pieci',),
    6: ('seši',),
    7: ('septiņi',),
    8: ('astoņi',),
    9: ('deviņi',),
}

TENS = {
    0: ('desmit',),
    1: ('vienpadsmit',),
    2: ('divpadsmit',),
    3: ('trīspadsmit',),
    4: ('četrpadsmit',),
    5: ('piecpadsmit',),
    6: ('sešpadsmit',),
    7: ('septiņpadsmit',),
    8: ('astoņpadsmit',),
    9: ('deviņpadsmit',),
}

TWENTIES = {
    2: ('divdesmit',),
    3: ('trīsdesmit',),
    4: ('četrdesmit',),
    5: ('piecdesmit',),
    6: ('sešdesmit',),
    7: ('septiņdesmit',),
    8: ('astoņdesmit',),
    9: ('deviņdesmit',),
}

HUNDRED = ('simts', 'simti', 'simtu')

THOUSANDS = {
    1: ('tūkstotis', 'tūkstoši', 'tūkstošu'),
    2: ('miljons', 'miljoni', 'miljonu'),
    3: ('miljards', 'miljardi', 'miljardu'),
    4: ('triljons', 'triljoni', 'triljonu'),
    5: ('kvadriljons', 'kvadriljoni', 'kvadriljonu'),
    6: ('kvintiljons', 'kvintiljoni', 'kvintiljonu'),
    7: ('sikstiljons', 'sikstiljoni', 'sikstiljonu'),
    8: ('septiljons', 'septiljoni', 'septiljonu'),
    9: ('oktiljons', 'oktiljoni', 'oktiljonu'),
    10: ('nontiljons', 'nontiljoni', 'nontiljonu'),
}

GENERIC_DOLLARS = ('dolārs', 'dolāri', 'dolāru')
GENERIC_CENTS = ('cents', 'centi', 'centu')

GENERIC_KRONA = ('krona', 'kronas', 'kronu')
GENERIC_ERA = ('ēre', 'ēras', 'ēru')


class Num2Word_LV(Num2Word_Base):
    """
    Sadly we have a legal form (used in legal and finance documents):
    http://www.eiro.lv/files/upload/files/Eiro_rakstiba-1.pdf
    https://likumi.lv/doc.php?id=254741
    http://eur-lex.europa.eu/legal-content/LV/TXT/HTML/?uri=CELEX:31998R0974&from=LV

    Source: http://publications.europa.eu/code/lv/lv-5000500.htm
    """
    CURRENCY_FORMS = {
        'AUD': (GENERIC_DOLLARS, GENERIC_CENTS),
        'CAD': (GENERIC_DOLLARS, GENERIC_CENTS),
        # repalced by EUR
        'EEK': (GENERIC_KRONA, GENERIC_CENTS),
        'EUR': (('eiro', 'eiro', 'eiro'), GENERIC_CENTS),
        'EUR_LEGAL': (('euro', 'euro', 'euro'), GENERIC_CENTS),
        'GBP': (
            ('sterliņu mārciņa', 'sterliņu mārciņas', 'sterliņu mārciņu'),
            ('penss', 'pensi', 'pensu')),
        # replaced by EUR
        'LTL': (('lits', 'liti', 'litu'), GENERIC_CENTS),
        # replaced by EUR
        'LVL': (('lats', 'lati', 'latu'),
                ('santīms', 'santīmi', 'santīmu')),
        'USD': (GENERIC_DOLLARS, GENERIC_CENTS),
        'RUB': (('rublis', 'rubļi', 'rubļu'),
                ('kapeika', 'kapeikas', 'kapeiku')),
        'SEK': (GENERIC_KRONA, GENERIC_ERA),
        'NOK': (GENERIC_KRONA, GENERIC_ERA),
        'PLN': (('zlots', 'zloti', 'zlotu'),
                ('grasis', 'graši', 'grašu')),
    }

    CURRENCY_ADJECTIVES = {
        'AUD': 'Austrālijas',
        'CAD': 'Kanādas',
        'EEK': 'Igaunijas',
        'USD': 'ASV',
        'RUB': 'Kreivijas',
        'SEK': 'Zviedrijas',
        'NOK': 'Norvēģijas',
    }

    def setup(self):
        self.negword = "mīnus"
        self.pointword = "komats"

    def to_cardinal(self, number):
        n = str(number).replace(',', '.')
        base_str, n = self.parse_minus(n)
        if '.' in n:
            left, right = n.split('.')
            leading_zero_count = len(right) - len(right.lstrip('0'))
            decimal_part = ((ZERO[0] + ' ') * leading_zero_count +
                            self._int2word(int(right)))
            return '%s%s %s %s' % (
                base_str,
                self._int2word(int(left)),
                self.pointword,
                decimal_part
            )
        else:
            return "%s%s" % (base_str, self._int2word(int(n)))

    def pluralize(self, n, forms):
        form = 0 if (n % 10 == 1 and n % 100 != 11) else 1 if n != 0 else 2
        return forms[form]

    def to_ordinal(self, number):
        raise NotImplementedError()

    def _int2word(self, n):
        if n == 0:
            return ZERO[0]

        words = []
        chunks = list(splitbyx(str(n), 3))
        i = len(chunks)
        for x in chunks:
            i -= 1

            if x == 0:
                continue

            n1, n2, n3 = get_digits(x)

            if n3 > 0:
                if n3 == 1 and n2 == 0 and n1 > 0:
                    words.append(HUNDRED[2])
                elif n3 > 1:
                    words.append(ONES[n3][0])
                    words.append(HUNDRED[1])
                else:
                    words.append(HUNDRED[0])

            if n2 > 1:
                words.append(TWENTIES[n2][0])

            if n2 == 1:
                words.append(TENS[n1][0])
            elif n1 > 0 and not (i > 0 and x == 1):
                words.append(ONES[n1][0])

            if i > 0:
                words.append(self.pluralize(x, THOUSANDS[i]))

        return ' '.join(words)
